from flask import Flask, render_template

from helloworld.core import get_message


app = Flask(__name__)


@app.route("/")
def hello():
    return render_template('index.html',
        message=get_message())


def run_server():
    app.run()


from setuptools import setup, find_packages
import tag_counter
from os.path import join, dirname

setup(
    name='tag_counter',
    version=tag_counter.__version__,
    packages=find_packages(),
    include_package_data=True,
    # long_description=open(join(dirname(__file__), 'README.md')).read(),
    test_suite='tests',
    entry_points={
        'console_scripts': [
            'tag_counter = tag_counter.core:print_message',
            'serve = tag_counter.web:run_server',
        ]
    },
    install_requires=[
    'Flask==0.8'
    ]
)
